summaryrefslogtreecommitdiffstats
path: root/firmware/export/button.h
diff options
context:
space:
mode:
authorMaurus Cuelenaere <mcuelenaere@gmail.com>2008-08-23 09:46:38 +0000
committerMaurus Cuelenaere <mcuelenaere@gmail.com>2008-08-23 09:46:38 +0000
commit1392dc2144a4b1810ba5c421f54e05dc1a3a74c7 (patch)
tree7f7f7d6dd6ce00e8146896456549441d4e8153d7 /firmware/export/button.h
parent965d2af61f5035dcf5179b8539785de641a9f015 (diff)
downloadrockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.tar.gz
rockbox-1392dc2144a4b1810ba5c421f54e05dc1a3a74c7.zip
Commit FS#9308: differentiate between TOUCHPAD & TOUCHSCREEN
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@18338 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'firmware/export/button.h')
-rw-r--r--firmware/export/button.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/firmware/export/button.h b/firmware/export/button.h
index f47639b3c7..0b4c8fd2b0 100644
--- a/firmware/export/button.h
+++ b/firmware/export/button.h
@@ -60,30 +60,30 @@ void wheel_send_events(bool send);
int button_apply_acceleration(const unsigned int data);
#endif
-#define BUTTON_NONE 0x00000000
+#define BUTTON_NONE 0x00000000
/* Button modifiers */
-#define BUTTON_REL 0x02000000
-#define BUTTON_REPEAT 0x04000000
-#define BUTTON_TOUCHPAD 0x08000000
+#define BUTTON_REL 0x02000000
+#define BUTTON_REPEAT 0x04000000
+#define BUTTON_TOUCHSCREEN 0x08000000
-#ifdef HAVE_TOUCHPAD
+#ifdef HAVE_TOUCHSCREEN
#if !defined(BUTTON_TOPLEFT) || !defined(BUTTON_TOPMIDDLE) \
|| !defined(BUTTON_TOPRIGHT) || !defined(BUTTON_MIDLEFT) \
|| !defined(BUTTON_CENTER) || !defined(BUTTON_MIDRIGHT) \
|| !defined(BUTTON_BOTTOMLEFT) || !defined(BUTTON_BOTTOMMIDDLE) \
|| !defined(BUTTON_BOTTOMRIGHT)
#error Touchpad button mode BUTTON_* defines not set up correctly
#endif
-enum touchpad_mode {
- TOUCHPAD_POINT = 0, /* touchpad returns pixel co-ords */
- TOUCHPAD_BUTTON, /* touchpad returns BUTTON_* area codes
- actual pixel value will still be accessable
- from button_get_data */
+enum touchscreen_mode {
+ TOUCHSCREEN_POINT = 0, /* touchscreen returns pixel co-ords */
+ TOUCHSCREEN_BUTTON, /* touchscreen returns BUTTON_* area codes
+ actual pixel value will still be accessable
+ from button_get_data */
};
/* maybe define the number of buttons in button-target.h ? */
-void touchpad_set_mode(enum touchpad_mode mode);
-enum touchpad_mode touchpad_get_mode(void);
+void touchscreen_set_mode(enum touchscreen_mode mode);
+enum touchscreen_mode touchscreen_get_mode(void);
#endif
#endif /* _BUTTON_H_ */
@@ -60,30 +60,30 @@ void wheel_send_events(bool send);
|| !defined(BUTTON_BOTTOMLEFT) || !defined(BUTTON_BOTTOMMIDDLE) \
|| !defined(BUTTON_BOTTOMRIGHT)
-#error Touchpad button mode BUTTON_* defines not set up correctly
+#error Touchscreen button mode BUTTON_* defines not set up correctly
#endif